@@ -1,10 +1,11 @@
 import json
 import logging
 import os
-from datetime import datetime
+from importlib import resources
 
 import fastjsonschema
 
+from metaphor import common
 from metaphor.common.metadata_change_event import (
     Dataset,
     EventHeader,
@@ -22,7 +23,7 @@ class EventUtil:
 
     kinesis_tenant = os.environ.get("KINESIS_TENANT", "default")
 
-    with open("metadata_change_event.json", "r") as f:
+    with resources.open_text(common, "metadata_change_event.json") as f:
         validate = fastjsonschema.compile(json.load(f))
 
     @staticmethod
