@@ -2,8 +2,6 @@ import json
 import logging
 from typing import Type
 
-from smart_open import open
-
 from metaphor.common.extractor import BaseExtractor, RunConfig
 
 logger = logging.getLogger()
@@ -21,20 +19,18 @@ def handle_api(
 
 
 def _handle_api(
-    event, context, runConfig: Type[RunConfig], extractor: Type[BaseExtractor]
+    event, context, config_cls: Type[RunConfig], extractor_cls: Type[BaseExtractor]
 ):
     params = json.loads(event["body"]) if "body" in event else event["params"]
     config_file = params.get("config_file", None)
     if config_file is None:
-        return {"statusCode": 422, "body": f"Missing 'config_file' parameter"}
+        return {"statusCode": 422, "body": "Missing 'config_file' parameter"}
 
-    with open(config_file, encoding="utf8") as fin:
-        config_dict = json.load(fin)
+    try:
+        run_config = config_cls.from_json_file(config_file)
+    except KeyError as e:
+        return {"statusCode": 422, "body": f"Missing {e} key in {config_file}"}
 
-    for key in runConfig.parameters():
-        if key not in config_dict:
-            return {"statusCode": 422, "body": f"Missing '{key}' key in {config_file}"}
-
-    actor = extractor()
-    actor.run(config=runConfig.build(config_dict))
+    actor = extractor_cls()
+    actor.run(config=run_config)
     return {"statusCode": 200, "body": json.dumps(params)}
