@@ -1,6 +1,8 @@
 import logging
 from dataclasses import dataclass
-from typing import Any, Dict, List, Tuple
+from typing import Dict, List, Tuple
+
+from dataclasses_json import dataclass_json
 
 from metaphor.common.event_util import EventUtil
 
@@ -30,29 +32,16 @@ logger = logging.getLogger()
 logger.setLevel(logging.INFO)
 
 
+@dataclass_json
 @dataclass
 class PostgresqlRunConfig(RunConfig):
-    redshift: bool  # whether the target is redshift or postgresql
     host: str
-    port: int
     database: str
     user: str
     password: str
 
-    @staticmethod
-    def parameters() -> List[str]:
-        return ["host", "database", "user", "password"]
-
-    @staticmethod
-    def build(obj: Any) -> "RunConfig":
-        return PostgresqlRunConfig(
-            "redshift" in obj,
-            obj["host"],
-            int(obj.get("port", 5432)),  # default to PostgreSQL port
-            obj["database"],
-            obj["user"],
-            obj["password"],
-        )
+    port: int = 5432
+    redshift: bool = False  # whether the target is redshift or postgresql
 
 
 class PostgresqlExtractor(BaseExtractor):
@@ -66,7 +55,8 @@ class PostgresqlExtractor(BaseExtractor):
     async def extract(self, config: RunConfig) -> List[MetadataChangeEvent]:
         assert isinstance(config, PostgresqlRunConfig)
 
-        logger.info(f"Fetching metadata from PostgreSQL host {config.host}")
+        platform = DataPlatform.REDSHIFT if config.redshift else DataPlatform.POSTGRESQL
+        logger.info(f"Fetching metadata from {platform} host {config.host}")
 
         conn = await self._connect_database(config, config.database)
         try:
@@ -78,7 +68,7 @@ class PostgresqlExtractor(BaseExtractor):
         for db in databases:
             conn = await self._connect_database(config, db)
             try:
-                tables = await self._fetch_tables(conn)
+                tables = await self._fetch_tables(conn, platform)
                 logger.info(f"DB {db} has tables {tables}")
 
                 # TODO: parallel fetching
@@ -115,7 +105,9 @@ class PostgresqlExtractor(BaseExtractor):
         results = await conn.fetch("SELECT datname FROM pg_database")
         return [r[0] for r in results if r[0] not in PostgresqlExtractor._ignored_dbs]
 
-    async def _fetch_tables(self, conn) -> List[Tuple[str, str, str]]:
+    async def _fetch_tables(
+        self, conn, platform: DataPlatform
+    ) -> List[Tuple[str, str, str]]:
         results = await conn.fetch(
             "SELECT table_catalog, table_schema, table_name, table_type "
             "FROM information_schema.tables "
@@ -130,7 +122,9 @@ class PostgresqlExtractor(BaseExtractor):
             name = table["table_name"]
             table_type = table["table_type"]
             full_name = self._dataset_name(catalog, schema, name)
-            self._datasets[full_name] = self._init_dataset(full_name, table_type)
+            self._datasets[full_name] = self._init_dataset(
+                full_name, table_type, platform
+            )
             tables.append((schema, name, full_name))
 
         return tables
@@ -191,11 +185,13 @@ class PostgresqlExtractor(BaseExtractor):
                 )
 
     @staticmethod
-    def _init_dataset(full_name: str, table_type: str) -> Dataset:
+    def _init_dataset(
+        full_name: str, table_type: str, platform: DataPlatform
+    ) -> Dataset:
         dataset = Dataset()
         dataset.entity_type = EntityType.DATASET
         dataset.logical_id = DatasetLogicalID()
-        dataset.logical_id.platform = DataPlatform.POSTGRESQL
+        dataset.logical_id.platform = platform
         dataset.logical_id.name = full_name
 
         dataset.schema = DatasetSchema()
